import { ControlElement, JsonSchema, JsonFormsRendererRegistryEntry, JsonFormsCellRendererRegistryEntry, RankedTester, EnumOption, DispatchPropsOfMultiEnumControl } from '@jsonforms/core';
import { DefineComponent, PropType, ComputedRef, Ref, ComponentOptionsMixin, PublicProps, ExtractPropTypes } from 'vue';
import { Styles } from '..';

declare const controlRenderer: DefineComponent<{
    schema: {
        required: true;
        type: PropType<JsonSchema>;
    };
    uischema: {
        required: true;
        type: PropType<ControlElement>;
    };
    path: {
        required: true;
        type: StringConstructor;
    };
    enabled: {
        required: false;
        type: BooleanConstructor;
        default: undefined;
    };
    renderers: {
        required: boolean;
        type: PropType< JsonFormsRendererRegistryEntry[]>;
        default: undefined;
    };
    cells: {
        required: boolean;
        type: PropType< JsonFormsCellRendererRegistryEntry[]>;
        default: undefined;
    };
    config: {
        required: boolean;
        type: ObjectConstructor;
        default: undefined;
    };
}, {
    control: ComputedRef<{
        uischema: ControlElement;
        schema: NonNullable< JsonSchema>;
        path: string;
        enabled: boolean;
        renderers: JsonFormsRendererRegistryEntry[];
        cells: JsonFormsCellRendererRegistryEntry[] & {
            tester: RankedTester;
            cell: any;
        }[];
        config: any;
        label: string;
        description: string;
        required: NonNullable<boolean | undefined>;
        i18nKeyPrefix: string;
        errors: string;
        data: any;
        rootSchema: NonNullable< JsonSchema>;
        id: string;
        visible: boolean;
        options: EnumOption[];
    }>;
} & DispatchPropsOfMultiEnumControl & {
    control: ComputedRef<{
        uischema: ControlElement;
        path: string;
        config: any;
        label: string;
        description: string;
        required: boolean;
        errors: string;
        id: string;
        visible: boolean;
    } & {
        errors: string;
    }>;
    styles: Styles;
    isFocused: Ref<boolean>;
    appliedOptions: ComputedRef<any>;
    controlWrapper: ComputedRef<{
        id: string;
        description: string;
        errors: string;
        label: string;
        visible: boolean;
        required: boolean;
    }>;
    onChange: (value: any) => void;
    vuetifyProps: (path: string) => any;
    persistentHint: () => boolean;
    computedLabel: ComputedRef<string>;
    touched: Ref<boolean>;
    handleBlur: () => void;
    handleFocus: () => void;
    rawErrors: ComputedRef<string>;
}, unknown, {
    checkboxGroupClasses(): string[];
}, {
    dataHasEnum(value: any): boolean;
    composePaths: (path1: string, path2: string) => string;
    toggle(value: any): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly< ExtractPropTypes<{
    schema: {
        required: true;
        type: PropType<JsonSchema>;
    };
    uischema: {
        required: true;
        type: PropType<ControlElement>;
    };
    path: {
        required: true;
        type: StringConstructor;
    };
    enabled: {
        required: false;
        type: BooleanConstructor;
        default: undefined;
    };
    renderers: {
        required: boolean;
        type: PropType< JsonFormsRendererRegistryEntry[]>;
        default: undefined;
    };
    cells: {
        required: boolean;
        type: PropType< JsonFormsCellRendererRegistryEntry[]>;
        default: undefined;
    };
    config: {
        required: boolean;
        type: ObjectConstructor;
        default: undefined;
    };
}>>, {
    enabled: boolean;
    renderers: JsonFormsRendererRegistryEntry[];
    cells: JsonFormsCellRendererRegistryEntry[];
    config: Record<string, any>;
}, {}>;
export default controlRenderer;
