import { ControlElement, JsonSchema, JsonFormsRendererRegistryEntry, JsonFormsCellRendererRegistryEntry, Translator, RankedTester } from '@jsonforms/core';
import { Ref, DefineComponent, PropType, ComputedRef, ComponentOptionsMixin, PublicProps, ExtractPropTypes } from 'vue';
import { MaskOptions } from 'maska';
import { Styles } from '..';

type ViewModeType = 'year' | 'months' | 'month';
declare const controlRenderer: DefineComponent<{
    schema: {
        required: true;
        type: PropType<JsonSchema>;
    };
    uischema: {
        required: true;
        type: PropType<ControlElement>;
    };
    path: {
        required: true;
        type: StringConstructor;
    };
    enabled: {
        required: false;
        type: BooleanConstructor;
        default: undefined;
    };
    renderers: {
        required: boolean;
        type: PropType< JsonFormsRendererRegistryEntry[]>;
        default: undefined;
    };
    cells: {
        required: boolean;
        type: PropType< JsonFormsCellRendererRegistryEntry[]>;
        default: undefined;
    };
    config: {
        required: boolean;
        type: ObjectConstructor;
        default: undefined;
    };
}, {
    views: ComputedRef<("year" | "month" | "day")[] | undefined>;
    viewMode: Ref<ViewModeType>;
    maska: {
        masked: string;
        unmasked: string;
        completed: boolean;
    };
    showMenu: Ref<boolean>;
    t: ComputedRef<Translator>;
    adaptValue: (value: any) => any;
    dateFormat: ComputedRef<string>;
    options: ComputedRef<MaskOptions> | null;
    useMask: boolean;
    control: ComputedRef<{
        uischema: ControlElement;
        schema: NonNullable<JsonSchema>;
        path: string;
        enabled: boolean;
        renderers: JsonFormsRendererRegistryEntry[];
        cells: JsonFormsCellRendererRegistryEntry[] & {
            tester: RankedTester;
            cell: any;
        }[];
        config: any;
        label: string;
        description: string;
        required: NonNullable<boolean | undefined>;
        i18nKeyPrefix: string;
        errors: string;
        data: any;
        rootSchema: NonNullable<JsonSchema>;
        id: string;
        visible: boolean;
    }> & ComputedRef<{
        uischema: ControlElement;
        path: string;
        config: any;
        label: string;
        description: string;
        required: boolean;
        errors: string;
        id: string;
        visible: boolean;
    } & {
        errors: string;
    }>;
    handleChange(path: string, value: any): void;
    styles: Styles;
    isFocused: Ref<boolean>;
    appliedOptions: ComputedRef<any>;
    controlWrapper: ComputedRef<{
        id: string;
        description: string;
        errors: string;
        label: string;
        visible: boolean;
        required: boolean;
    }>;
    onChange: (value: any) => void;
    vuetifyProps: (path: string) => any;
    persistentHint: () => boolean;
    computedLabel: ComputedRef<string>;
    touched: Ref<boolean>;
    handleBlur: () => void;
    handleFocus: () => void;
    rawErrors: ComputedRef<string>;
}, unknown, {
    pickerIcon(): string;
    dateSaveFormat(): string;
    formats(): string[];
    minDate(): string | undefined;
    maxDate(): string | undefined;
    inputModel: {
        get(): string | null;
        set(val: string | null): void;
    };
    pickerValue: {
        get(): Date | undefined;
        set(val: Date): void;
    };
    cancelLabel(): string;
    okLabel(): string;
    showActions(): boolean;
}, {
    onPickerChange(value: Date): void;
    updateDatePickerValue(val: unknown, proxyModel: Ref<Date | undefined>): void;
    updateDatePickerYear(year: number, proxyModel: Ref<Date | undefined>): void;
    updateDatePickerMonth(month: number, proxyModel: Ref<Date | undefined>): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly< ExtractPropTypes<{
    schema: {
        required: true;
        type: PropType<JsonSchema>;
    };
    uischema: {
        required: true;
        type: PropType<ControlElement>;
    };
    path: {
        required: true;
        type: StringConstructor;
    };
    enabled: {
        required: false;
        type: BooleanConstructor;
        default: undefined;
    };
    renderers: {
        required: boolean;
        type: PropType< JsonFormsRendererRegistryEntry[]>;
        default: undefined;
    };
    cells: {
        required: boolean;
        type: PropType< JsonFormsCellRendererRegistryEntry[]>;
        default: undefined;
    };
    config: {
        required: boolean;
        type: ObjectConstructor;
        default: undefined;
    };
}>>, {
    enabled: boolean;
    renderers: JsonFormsRendererRegistryEntry[];
    cells: JsonFormsCellRendererRegistryEntry[];
    config: Record<string, any>;
}, {}>;
export default controlRenderer;
